@@ -25,8 +25,8 @@
  * MUST not include config.h
  */
 
-#if (defined(__OpenBSD__) || \
-	!defined(_MSC_VER) && defined(__cplusplus) && __cplusplus >= 201103L) || \
+#if (!defined(_MSC_VER) && defined(__cplusplus) && __cplusplus >= 201103L) || \
+	(defined(_MSC_VER) && _MSC_VER >= 1600) || \
 	(defined(__STDC_VERSION__) && __STDC_VERSION__ >= 199901L)
 #  include <stdint.h>
 #elif (defined(__sun) && defined(__SVR4)) || defined(__hpux)
@@ -52,8 +52,8 @@ typedef unsigned char     uint8_t;	/* 8-bit int */
   typedef unsigned  short  uint16_t;	/* 16-bit int */
   typedef   signed  int   int32_t;	/* 32-bit int */
   typedef unsigned  int  uint32_t;	/* 32-bit int */
-  typedef   signed  long   int64_t;	/* 64-bit int */
-  typedef unsigned  long  uint64_t;	/* 64-bit int */
+  typedef   signed  long long   int64_t;	/* 64-bit int */
+  typedef unsigned  long long  uint64_t;	/* 64-bit int */
 #  endif
 #endif
 
